@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: esqueleto
 version: 2.4.3
-id: esqueleto-2.4.3-1811f340ff0dc33d46d950dbd44a06e4
-key: esque_4jVO72Vt0R6EpTBvplRbUc
+id: esqueleto-2.4.3-a13a95ac309066dbfab8f0c73b113d4e
+key: esque_AX85RRRNKFfAPeEFCLwGFn
 license: BSD3
 copyright: (c) 2012-2015 Felipe Almeida Lessa
 maintainer: felipe.lessa@gmail.com
@@ -52,15 +52,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/esqueleto-2.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/esqueleto-2.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/esqueleto-2.4.3
-hs-libraries: HSesqueleto-2.4.3-4jVO72Vt0R6EpTBvplRbUc
+hs-libraries: HSesqueleto-2.4.3-AX85RRRNKFfAPeEFCLwGFn
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    monad-logger-0.3.18-8d0d3ee0b0c9e28288fbc3f8ad4970cb
-    persistent-2.2.4.1-b198a8037ee23ace95ee55f6faca82c3
-    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    monad-logger-0.3.18-1374b457a8b7165408364c0bd477c532
+    persistent-2.2.4.1-53b32e0b8931dd68fbb356ac374c65f3
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
